#!/bin/bash

RUNDIR=$(pwd)

# Remove eventual leftovers
rm -rf AutoRPE/   ../Remote/ProcessedOutputs/

#download last AutoRPE version
#git clone http://earth.bsc.es/gitlab/otinto/AutoRPE.git
git clone http://earth.bsc.es/gitlab/otinto/AutoRPE.git --branch dwarf-lonlev-0.91_0


DWARF=/home/Earth/sparonuz/Documents/Codes/dwarf-lonlev-0.91_0
DWARF_SRC=${DWARF}/src
if [[ ! -d ${DWARF_SRC} ]]
then
  echo -e "the folder" ${DWARF_SRC} " does not exist\nAbort..."
  exit 1
fi

AutoRPE_Input=${RUNDIR}/AutoRPE/ModelSources/Input/
AutoRPE_Output=${RUNDIR}/AutoRPE/ModelSources/Output/

# Folder on HPC in which the remote implementation will run
REMOTE_DIR=/home/bsc32/bsc32402/local/
# Copy just sources
cp ${DWARF_SRC}/*.f90 ${AutoRPE_Input}

# Precompile files when needed
for file in ${DWARF_SRC}/*.F90
do
 dest_file=${file//${DWARF_SRC}}
 cpp -P -fopenmp  ${file} > ${AutoRPE_Input}/${dest_file//F90}f90
done

# Remove legacy files
rm ${AutoRPE_Input}/*_legacy*

# Ignore opmpi files and timings, which contains no calculation at all
echo -e  \
 'dmi_omp.F90' \
 '\ndmi_omp.f90' \
 '\ndmi_timer.f90' > AutoRPE/AdditionalFiles/list_of_files_to_keep_unmodified.txt


# Check python is loaded
python3 -V  >/dev/null 2>&1  ||  { echo "load python3 and try again ..."; exit 1 ; }

cd ${RUNDIR}/AutoRPE

# Run the implementation
python3 ImplementRPEtoSource.py 2> implementation.log

ls ${AutoRPE_Output}

mkdir  ${RUNDIR}/../Remote/ProcessedOutputs

cp ${AutoRPE_Output}/* ${RUNDIR}/../Remote/ProcessedOutputs
cp -r ${DWARF} ${RUNDIR}/../Remote

#coping files to remote
scp -r ${RUNDIR//Local} mn1.bsc.es:${REMOTE_DIR}
